package com.persagy.adm.server.custom.controller;


import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.persagy.adm.server.custom.common.AdmResult;
import com.persagy.adm.server.custom.dao.AdmFileMapper;
import com.persagy.adm.server.custom.entity.db.AdmCad;
import com.persagy.adm.server.custom.entity.CadFileQueryParam;
import com.persagy.adm.server.custom.service.IAdmCadService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * ADM文件服务
 * @author yanguofeng
 * @since 2022-01-10
 */
@RestController
@RequestMapping("/adm/adm-file")
public class AdmFileController {

    @Autowired
    IAdmCadService iAdmCadService;
    @Autowired
    AdmFileMapper admFileMapper;

    /**
     * CAD文件查询接口
     */

    @PostMapping("/queryCadFiles")
    public AdmResult<List<AdmCad>> queryCadFiles(@RequestBody CadFileQueryParam queryParam){
        Wrapper<AdmCad> eq = new LambdaQueryWrapper<AdmCad>()
                .eq(StringUtils.isNotBlank(queryParam.getProjectId()), AdmCad::getProjectId, queryParam.getProjectId())
                .eq(StringUtils.isNotBlank(queryParam.getBuildingId()),AdmCad::getBuildingId,queryParam.getBuildingId())
                .eq(StringUtils.isNotBlank(queryParam.getFloorId()),AdmCad::getFloorId,queryParam.getFloorId())
                .eq(StringUtils.isNotBlank(queryParam.getFileKey()),AdmCad::getFileKey,queryParam.getFileKey())
                .eq(StringUtils.isNotBlank(queryParam.getMajorCode()),AdmCad::getMajorCode,queryParam.getMajorCode());
        return AdmResult.success(iAdmCadService.list(eq));
    }

    /**
     * 保存CAD文件信息
     */
    @PostMapping("/saveCadFileInfo")
    public AdmResult<Void> saveCadFileInfo(@RequestBody List<AdmCad> admFiles){
        iAdmCadService.saveOrUpdateBatch(admFiles);
        return AdmResult.success(null);
    }

    /**
     * 删除CAD文件信息
     * @param id 文件信息表主键ID
     */
    @PostMapping("/delete")
    public AdmResult<Void> delete(@RequestParam("id") String id){
        iAdmCadService.removeById(id);
        return AdmResult.success(null);
    }
}
